@@ -1,6 +1,8 @@
 import logging
 
-DEFAULT_CHUNK_SIZE_IN_MB = 25
+from intersection.consts import NEW_LINE_CHARACTER
+
+DEFAULT_CHUNK_SIZE_IN_MB = 100
 
 
 def chunk_file(file_path: str, chunk_size=None):
@@ -23,14 +25,22 @@ def chunk_file(file_path: str, chunk_size=None):
             chunk = f.readlines(chunk_size)
 
 
-def next_value(file_cursor):
+def next_value(file_cursor, skip_previous_value=None):
     """
     Reads the next available and value
     :param file_cursor: the cursor to the opened file
+    :param skip_previous_value: the value to be skipped
     :return: the integer value, None if not available
     """
-    value = file_cursor.readline() if file_cursor else None
-    return int(value) if value else None
+    value = None
+    if file_cursor:
+        value = file_cursor.readline()
+        value = int(value) if value else None
+        skip_previous_value = skip_previous_value if skip_previous_value else None
+        while skip_previous_value and value and skip_previous_value == value:
+            value = file_cursor.readline()
+            value = int(value) if value else None
+    return value
 
 
 def write_value(file_cursor, value: int):
@@ -40,4 +50,4 @@ def write_value(file_cursor, value: int):
     :param value: the value to be written
     """
     file_cursor.write(str(value))
-    file_cursor.write("\n")
+    file_cursor.write(NEW_LINE_CHARACTER)
